# -*- coding: utf-8 -*-
# Copyright (C) 2022 Nilesh Debix
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""A linter for AWS step functions files."""


APP_NAME = "stepfunction_validator"
APP_VERSION = "0.0.2"
APP_DESCRIPTION = __doc__

__author__ = u"Nilesh Debix"
__copyright__ = u"Copyright 2022, Nilesh Debix"
__license__ = "GPLv3"
__version__ = APP_VERSION
